summaryrefslogtreecommitdiffstats
path: root/tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py')
-rw-r--r--tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py b/tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py
index d7dc35689..0bec68b8f 100644
--- a/tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py
+++ b/tests/functional/dht/test_volume_start_stop_while_rebalance_in_progress.py
@@ -208,14 +208,14 @@ class RebalanceValidation(GlusterBaseClass):
self.volname))
g.log.info("Volume %s state is \"Started\"", self.volname)
- @classmethod
- def tearDownClass(cls):
- # Unmount Volume and Cleanup Volume
+ def tearDown(self):
+
+ # Unmount and cleanup original volume
g.log.info("Starting to Unmount Volume and Cleanup Volume")
- ret = cls.unmount_volume_and_cleanup_volume(mounts=cls.mounts)
+ ret = self.unmount_volume_and_cleanup_volume(mounts=self.mounts)
if not ret:
- raise ExecutionError("Failed to Unmount Volume and Cleanup Volume")
- g.log.info("Volume %s unmount and cleanup: Success", cls.volname)
+ raise ExecutionError("Failed to umount the vol & cleanup Volume")
+ g.log.info("Successful in umounting the volume and Cleanup")
- # Calling GlusterBaseClass tearDownClass
- cls.get_super_method(cls, 'tearDownClass')()
+ # Calling GlusterBaseClass tearDown
+ self.get_super_method(self, 'tearDown')()